package java.beans;

import java.util.WeakHashMap;
import java.awt.GraphicsEnvironment;
import com.sun.beans.finder.PropertyEditorFinder;
import com.sun.beans.finder.BeanInfoFinder;
import java.util.Map;

final class ThreadGroupContext
{
    private static final WeakIdentityMap<ThreadGroupContext> contexts;
    private volatile boolean isDesignTime;
    private volatile Boolean isGuiAvailable;
    private Map<Class<?>, BeanInfo> beanInfoCache;
    private BeanInfoFinder beanInfoFinder;
    private PropertyEditorFinder propertyEditorFinder;
    
    static ThreadGroupContext getContext() {
        return (ThreadGroupContext)ThreadGroupContext.contexts.get(Thread.currentThread().getThreadGroup());
    }
    
    private ThreadGroupContext() {
    }
    
    boolean isDesignTime() {
        return this.isDesignTime;
    }
    
    void setDesignTime(boolean isDesignTime) {
        this.isDesignTime = isDesignTime;
    }
    
    boolean isGuiAvailable() {
        Boolean isGuiAvailable = this.isGuiAvailable;
        return (isGuiAvailable != null) ? ((boolean)isGuiAvailable) : (!GraphicsEnvironment.isHeadless());
    }
    
    void setGuiAvailable(boolean b) {
        this.isGuiAvailable = Boolean.valueOf(b);
    }
    
    BeanInfo getBeanInfo(Class<?> clazz) {
        return (this.beanInfoCache != null) ? ((BeanInfo)this.beanInfoCache.get(clazz)) : null;
    }
    
    BeanInfo putBeanInfo(Class<?> clazz, BeanInfo beanInfo) {
        if (this.beanInfoCache == null) {
            this.beanInfoCache = new WeakHashMap();
        }
        return (BeanInfo)this.beanInfoCache.put(clazz, beanInfo);
    }
    
    void removeBeanInfo(Class<?> clazz) {
        if (this.beanInfoCache != null) {
            this.beanInfoCache.remove(clazz);
        }
    }
    
    void clearBeanInfoCache() {
        if (this.beanInfoCache != null) {
            this.beanInfoCache.clear();
        }
    }
    
    synchronized BeanInfoFinder getBeanInfoFinder() {
        if (this.beanInfoFinder == null) {
            this.beanInfoFinder = new BeanInfoFinder();
        }
        return this.beanInfoFinder;
    }
    
    synchronized PropertyEditorFinder getPropertyEditorFinder() {
        if (this.propertyEditorFinder == null) {
            this.propertyEditorFinder = new PropertyEditorFinder();
        }
        return this.propertyEditorFinder;
    }
    
    ThreadGroupContext(ThreadGroupContext.1 weakIdentityMap) {
        this();
    }
    
    static {
        contexts = new WeakIdentityMap<ThreadGroupContext>() {
            @Override
            protected ThreadGroupContext create(Object o) {
                return new ThreadGroupContext();
            }
        };
    }
}
